==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SliceClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceClickEventArgsDescription } from "./SliceClickEventArgsDescription";
/**
 * @hidden
 */
export let SliceClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SliceClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SliceClickEventArgsDescriptionMetadata.a == null) {
                SliceClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SliceClickEventArgsDescriptionMetadata.c(SliceClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(SliceClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SliceClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsSelected", "Boolean");
            a.item("IsExploded", "Boolean");
            a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
        }
        static d(a) {
            SliceClickEventArgsDescriptionMetadata.b(a);
            a.aa("SliceClickEventArgs", () => new SliceClickEventArgsDescription());
            a.z("SliceClickEventArgs", SliceClickEventArgsDescriptionMetadata.a);
        }
    }
    SliceClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SliceClickEventArgsDescriptionMetadata, 'SliceClickEventArgsDescriptionMetadata');
    SliceClickEventArgsDescriptionMetadata.a = null;
    return SliceClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SliceClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceClickEventArgsDescription } from "./SliceClickEventArgsDescription";
/**
 * @hidden
 */
export let SliceClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SliceClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SliceClickEventArgsDescriptionMetadata.a == null) {
                SliceClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SliceClickEventArgsDescriptionMetadata.c(SliceClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(SliceClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SliceClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsSelected", "Boolean");
            a.item("IsExploded", "Boolean");
            a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
        }
        static d(a) {
            SliceClickEventArgsDescriptionMetadata.b(a);
            a.ac("SliceClickEventArgs", () => new SliceClickEventArgsDescription());
            a.ab("SliceClickEventArgs", SliceClickEventArgsDescriptionMetadata.a);
        }
    }
    SliceClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SliceClickEventArgsDescriptionMetadata, 'SliceClickEventArgsDescriptionMetadata');
    SliceClickEventArgsDescriptionMetadata.a = null;
    return SliceClickEventArgsDescriptionMetadata;
})();
